texfigure: Python Helpers for PythonTeX
---------------------------------------

texfigure is a package designed to make it easier to work with matplotlib and
other figures inside PythonTeX documents.


.. automodapi:: texfigure


